@@ -91,15 +91,16 @@ CIM <- function(data,
   ###--------------------------------------------------------------------------
 
   if (!requireNamespace("psych", quietly = TRUE)) {
-    stop("To do the exploratory factor analysis, the \"psych\" package is required. ",
-         "Please install it using `install.packages('psych');`.",
-         call. = FALSE);
+    message("To do the exploratory factor analysis, the \"psych\" package is required. ",
+            "Please install it using `install.packages('psych');`.");
+    return(invisible(FALSE));
   }
 
   if (!requireNamespace("GPArotation", quietly = TRUE)) {
-    stop("To do the exploratory factor analysis, the \"GPArotation\" package is required. ",
-         "Please install it using `install.packages('GPArotation');`.",
-         call. = FALSE);
+    message("To do the exploratory factor analysis, the \"GPArotation\" package is required. ",
+            "Please install it using `install.packages('GPArotation');`.");
+    return(invisible(FALSE));
+
   } else {
     ### This is just to satisfy R CHECK - otherwise we're not "allowed" to
     ### check whether GPArotation exists, and `psych` doesn't handle that
@@ -108,9 +109,9 @@ CIM <- function(data,
   }
 
   if (!requireNamespace("lavaan", quietly = TRUE)) {
-    stop("To do the confirmatory factor analysis, the \"lavaan\" package is required. ",
-         "Please install it using `install.packages('lavaan');`.",
-         call. = FALSE);
+    message("To do the confirmatory factor analysis, the \"lavaan\" package is required. ",
+            "Please install it using `install.packages('lavaan');`.");
+    return(invisible(FALSE));
   }
 
   ###--------------------------------------------------------------------------
